@@ -10,7 +10,7 @@ import sys
 
 
 class ProgressBar(object):
-    def __init__(self, items=None, completed=0, maxlen=25, char='█', show_on_update=False, ips=1, lsttime=None, learning_rate=.1):
+    def __init__(self, items=None, completed=0, maxlen=25, char='█', show_on_update=True, ips=1, lsttime=None, learning_rate=.1):
         self.completed = completed
         self.items = items
         self.maxlen = maxlen
@@ -45,7 +45,7 @@ class ProgressBar(object):
     def __iadd__(self, other):
         a = ProgressBar(self.items, self.completed, self.maxlen, self.char,
                         self.show_on_update, self.items_per_sec, self.last_time, self.lr)
-        a.update(self.completed + other)
+        a.update(other)
         return a
 
     def format_time(self):
@@ -67,12 +67,11 @@ class ProgressBar(object):
 {str(round(self.pos*100,2)).ljust(5)}% \
 [{(self.char*int(self.pos*self.maxlen)).ljust(self.maxlen)}] {st}\t')
 
-    def update(self, completed=None):
-        if completed == None:
-            completed = self.completed + 1
+    def update(self, n=1):
+        completed = self.completed + n
         if self.items:
             t = time.time() - self.last_time
-            if t != 0:
+            if t != 0 or completed == self.completed:
                 comp = completed - self.completed
                 self.items_per_sec += self.lr * (comp/t - self.items_per_sec)
                 self.last_time = time.time()
